Documentation
¶
Overview ¶
Package workspace finds Pawn project roots.
Index ¶
Constants ¶
const ( ManifestJSON = "pawn.json" ManifestYAML = "pawn.yaml" )
ManifestJSON and ManifestYAML are supported manifest names.
Variables ¶
var ErrNotFound = errors.New("workspace: no pawn.json or pawn.yaml found")
ErrNotFound is returned by FindRoot when no manifest is found between start and the filesystem root.
Functions ¶
Types ¶
type Root ¶
type Root struct {
Dir string // Dir is the absolute, slash-separated directory containing the manifest.
ManifestPath string // ManifestPath is the absolute, slash-separated path to the manifest file that was found.
ManifestName string // ManifestName is the base filename of the manifest that was found
}
Root identifies a discovered project root.
Click to show internal directories.
Click to hide internal directories.